@@ -1,7 +1,7 @@
 """Contains the s3 wrapper class."""
+import itertools
 import os
 import re
-import itertools
 from typing import Any, Dict, Generator, List, Optional, Sequence, Tuple, Union
 
 from botocore.exceptions import ClientError
@@ -53,8 +53,8 @@ class S3(BaseSession):
         """Set both bucket and path.
 
         This is used to process argument of "-b bucket/object", if any of them is set,
-        skip further fzf selection. 
-        
+        skip further fzf selection.
+
         E.g. if bucket is set, skip select bucket. If both bucket and object is set, skip
         all fzf selection.
 
@@ -232,7 +232,7 @@ class S3(BaseSession):
         no_progress: bool = False,
     ) -> List[Dict[str, str]]:
         """List object versions through fzf.
-        
+
         :param bucket: object's bucketname, if not set, class instance's bucket_name will be used
         :type bucket: str, optional
         :param key: object's key, if not set, class instance's path_list[0] will be used
@@ -391,7 +391,9 @@ class S3(BaseSession):
     def _validate_input_path(
         self, user_input
     ) -> Union[
-        Tuple[str, Sequence[str]], Tuple[str, Sequence[str]], Tuple[None, None],
+        Tuple[str, Sequence[str]],
+        Tuple[str, Sequence[str]],
+        Tuple[None, None],
     ]:
         """Validate if the user input path is valid format.
 
@@ -440,7 +442,7 @@ class S3(BaseSession):
 
     def _version_generator(
         self, versions: List[dict], markers: List[dict], non_current: bool, delete: bool
-    ) -> Generator[Dict[str, str], None, None]:
+    ) -> Generator[Dict[str, Any], None, None]:
         """Create version generator to reduce memory usage.
 
         :param versions: list of versions from list_object_versions paginator
@@ -452,7 +454,7 @@ class S3(BaseSession):
         :param delete: include delete marker
         :type delete: bool
         :return: formatted dict of version information in generator form
-        :rtype: Generator[Dict[str,str], None, None]
+        :rtype: Generator[Dict[str,Any], None, None]
         """
         for version in versions:
             if (non_current and not version.get("IsLatest")) or not non_current:
@@ -483,7 +485,7 @@ class S3(BaseSession):
         solutions, although this handle one less edge case (if user delete a version object
         but then created a new object with the same name), this is much faster and better
         in memory usage.
-        
+
         :param results: the result from boto3 paginator
         :type results: List[Dict[str, Any]]
         :param onlydelete: boolean indicator indicates whether to only show deletemark.
